@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef __GLADE_ACCUMULATORS_H__
 #define __GLADE_ACCUMULATORS_H__
 
@@ -10,6 +9,11 @@ gboolean glade_single_object_accumulator   (GSignalInvocationHint *ihint,
 					    GValue                *return_accu,
 					    const GValue          *handler_return,
 					    gpointer               dummy);
+
+gboolean glade_integer_handled_accumulator (GSignalInvocationHint *ihint,
+					    GValue                *return_accu,
+					    const GValue          *handler_return,
+					    gpointer               dummy);
 					    
 gboolean glade_boolean_handled_accumulator (GSignalInvocationHint *ihint,
 					    GValue                *return_accu,
